==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/fr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Agenda",
    "%s has published the calendar \"%s\"" : "%s a publié le calendrier \"%s\"",
    "Too many redirects. Aborting ..." : "Trop de redirections. Annulation en cours...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Ce serveur distant ne semble pas nous donner accès au calendrier (erreur HTTP {%s})",
    "Error connecting to remote server" : "Erreur de connexion au serveur distant",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Erreur lors de la demande de ressources auprès du serveur distant. Cela pourrait être liée à une incompatibilité de certificat",
    "Error requesting resource on remote server" : "Erreur lors de la demande de ressources auprès du serveur distant.",
    "Individual" : "Individuel",
    "Group" : "Groupe",
    "Resource" : "Ressource",
    "Room" : "Lieu",
    "Unknown" : "Inconnu",
    "Required" : "Requis",
    "Optional" : "Optionnel",
    "Does not attend" : "Ne participera pas",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Vous êtes dans un fuseau horaire inconnu ({tz}), retour à UTC",
    "Please create a calendar first." : "Veuillez d'abord créer un calendrier.",
    "New event" : "Nouvel événement",
    "CalDAV address for clients" : "Adresse CalDAV pour les clients",
    "Error saving WebCal-calendar" : "Erreur lors de la sauvegarde du calendrier WebCal",
    "WebDAV address for subscriptions" : "Adresse WebDAV pour s'inscrire",
    "EMail has been sent." : "L'EMail a été envoyé.",
    "There was an issue while sending your EMail." : "Il y a eu un problème lors de l'envoi de votre EMail.",
    "group" : "groupe",
    "Details" : "Détails",
    "Attendees" : "Participants",
    "Reminders" : "Rappels",
    "Repeating" : "Occurrences",
    "When shared show full event" : "Afficher l'événement complet en cas de partage",
    "When shared show only busy" : "Afficher seulement la plage horaire occupée en cas de partage",
    "When shared hide this event" : "Masquer cet événement en cas de partage",
    "Confirmed" : "Confirmé",
    "Tentative" : "Tentative",
    "Cancelled" : "Annulé",
    "Please add a title!" : "Veuillez ajouter un titre !",
    "Please select a calendar!" : "Veuillez sélectionner un calendrier !",
    "The event ends before it starts!" : "L'évènement se termine avant qu'il ne commence !",
    "Global" : "Global",
    "None" : "Aucun",
    "Every day" : "Chaque jour",
    "Every week" : "Chaque semaine",
    "Every month" : "Chaque mois",
    "Every year" : "Chaque année",
    "never" : "jamais",
    "after" : "après ",
    "How about getting started by importing some calendars?" : "Pourquoi ne pas commencer par importer quelques calendriers ?",
    "At time of event" : "À l'heure de l'événement",
    "5 minutes before" : "5 minutes avant",
    "10 minutes before" : "10 minutes avant",
    "15 minutes before" : "15 minutes avant",
    "30 minutes before" : "30 minutes avant",
    "1 hour before" : "1 heure avant",
    "2 hours before" : "2 heures avant",
    "Custom" : "Personnalisé",
    "Audio" : "Son",
    "E Mail" : "Courriel",
    "Pop up" : "Fenêtre d'alerte",
    "sec" : "sec",
    "min" : "min",
    "hours" : "heures",
    "days" : "jours",
    "week" : "semaine",
    "before" : "avant",
    "start" : "début",
    "end" : "fin",
    "Editing reminders of unknown type not supported." : "L'édition de rappels de type inconnu n'est pas supportée.",
    "Week {number} of {year}" : "Semaine {number} de {year}",
    "Successfully imported" : "Importé avec succès",
    "Partially imported, 1 failure" : "Partiellement importé, 1 échec",
    "Partially imported, {n} failures" : "Partiellement importé, {n} échecs",
    "Audio alarm" : "Alerte audio",
    "Pop-up" : "Fenêtre d'alerte",
    "E-Mail" : "Courriel",
    "{type} {time} before the event starts" : "{type} {time} avant l'événement",
    "{type} {time} before the event ends" : "{type} {time} avant la fin de l'événement",
    "{type} {time} after the event starts" : "{type} {time} après le début de l'événement",
    "{type} {time} after the event ends" : "{type} {time} après la fin de l'événement",
    "{type} at the event's start" : "{type} au début de l'événement",
    "{type} at the event's end" : "{type} à la fin de l'événement",
    "{type} at {time}" : "{type} à {time}",
    "{calendar} shared by {owner}" : "{calendar} partagé par {owner}",
    "Please enter a valid WebCal-URL" : "Veuillez saisir une URL WebCal valide",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Erreur grave du mandataire webcal.  Communiquez avec votre administrateur de réseau pour plus de renseignements.",
    "Title of the Event" : "Titre de l'événement",
    "Starts" : "Commence",
    "Ends" : "Termine",
    "All day Event" : "Journée entière",
    "Delete" : "Supprimer",
    "Cancel" : "Annuler",
    "More ..." : "Plus…",
    "Create" : "Créer",
    "Update" : "Mettre à jour",
    "Close" : "Fermer",
    "Location" : "Emplacement",
    "Description" : "Description",
    "Event status" : "Statut de l'événement",
    "Visibility when sharing" : "Visibilité pendant le partage",
    "Export" : "Exporter",
    "%s has published the calendar %s" : "%s a publié l'agenda %s",
    "Hello," : "Bonjour,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Nous voulions vous informer que %s a publié l'agenda {boldstart}%s{boldend}.",
    "Click here to access it" : "Cliquez ici pour y accéder",
    "Cheers!" : "À bientôt !",
    "We wanted to inform you that %s has published the calendar %s." : "Nous voulions vous informer que %s a publié l'agenda %s.",
    "Click on the link below to access it" : "Cliquez sur le lien ci-dessous pour y accéder",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A cause d'un bug en amont, le calendrier ne peut actuellement pas prendre en charge la fonction de pipeline d'actifs.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Veuillez contacter votre administrateur afin de lui demander de désactiver l'option de configuration \"asset-pipeline.enabled\".",
    "Day" : "Jour",
    "Week" : "Semaine",
    "Month" : "Mois",
    "Today" : "Auj.",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Certains événements de cet agenda sont cassés. Merci de consulter la console JS pour plus d'info.",
    "Share Calendar" : "Partager l'agenda",
    "Shared" : "Partagé",
    "More" : "Plus",
    "Edit" : "Éditer",
    "Link" : "Lien",
    "iCal link" : "Lien iCal",
    "Download" : "Télécharger",
    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
    "can edit" : "peut modifier",
    "Share link" : "Partager un lien",
    "Public access" : "Accès public",
    "Email link to person" : "Envoyer un lien par courriel",
    "Send" : "Envoyer",
    "New Calendar" : "Nouvel agenda",
    "Name" : "Nom",
    "New Subscription" : "Nouvel abonnement",
    "Go back" : "Aller au précédent",
    "Go forward" : "Aller au suivant",
    "Calendar does not exist" : "L'agenda n'existe pas",
    "Maybe you got a wrong link or the calendar was unshared?" : "Vous avez peut-être obtenu un mauvais lien ou le partage de l'agenda a été annulé ?",
    "Edit event" : "Modifier l'événement",
    "Delete Event" : "Supprimer l'événement",
    "Save Event" : "Enregistrer l'événement",
    "Time" : "Heure",
    "Type" : "Type",
    "Relative" : "Relatif",
    "Absolute" : "Absolu",
    "Repeat" : "Répéter",
    "times every" : "Répéter tous les",
    "Add" : "Ajouter",
    "E-Mail address of attendee" : "Adresse courriel du participant",
    "Please add your email address in the personal settings in order to add attendees." : "Veuillez ajouter votre adresse mail dans les paramètres du comptes  dans l'ordre pour ajouter des participants .",
    "from" : "du",
    "to" : "à",
    "This event's repeating rule is not supported yet." : "La répétition de cet évènement n'est pas prise en charge pour le moment.",
    "Support for advanced rules will be added with subsequent updates." : "Le support de règles multiples sera ajouté dans des mises à jour ultérieures.",
    "Reset repeating rule" : "Réinitialiser la règle de répétition",
    "Repeat every ..." : "Répéter tous les…",
    "end repeat ..." : "arrêter la répétition…",
    "times" : "fois",
    "Import Calendars" : "Importer des agendas",
    "Import canceled" : "Importation annulée",
    "Analyzing calendar" : "Analyse de l'agenda en cours",
    "The file contains objects incompatible with the selected calendar" : "Le fichier contient des objets incompatibles avec l'agenda sélectionné",
    "New calendar" : "Nouvel agenda",
    "File is empty" : "Le fichier est vide",
    "Import scheduled" : "Importation planifiée",
    "%s shared the calendar <strong>%s</strong> with you" : "%s a partagé l'agenda <strong>%s</strong> avec vous",
    "Embed" : "Embarquer",
    "IFrame to integrate" : "IFrame à intégrer",
    "Publish URL" : "Publier l'URL",
    "Settings & import" : "Paramètres & Importation",
    "Skip simple event editor" : "Passer l'éditeur d'évènement simple",
    "Show week numbers" : "Afficher les numéros de semaine",
    "Import calendar" : "Importer un agenda",
    "No Calendars selected for import" : "Aucun agenda sélectionné pour import",
    "Primary CalDAV address" : "Adresse CalDAV principale",
    "iOS/OS X CalDAV address" : "Adresse CalDAV pour iOS/OS X",
    "Subscribe" : "S'abonner"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-calendar-1.5.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/fr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Agenda",
    "%s has published the calendar »%s«" : "%s a publié l'agenda «%s»",
    "Hello," : "Bonjour,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Nous voulions vous informer que %s a publié l'agenda « %s ».",
    "Open »%s«" : "Ouvrir «%s»",
    "Cheers!" : "À bientôt !",
    "Recipient" : "Destinataire",
    "Too many redirects. Aborting ..." : "Trop de redirections. Annulation en cours...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Ce serveur distant ne semble pas nous donner accès au calendrier (erreur HTTP {%s})",
    "Error connecting to remote server" : "Erreur de connexion au serveur distant",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Erreur lors de la demande de ressources auprès du serveur distant. Cela pourrait être liée à une incompatibilité de certificat",
    "Error requesting resource on remote server" : "Erreur lors de la demande de ressources auprès du serveur distant.",
    "Individual" : "Individuel",
    "Group" : "Groupe",
    "Resource" : "Ressource",
    "Room" : "Lieu",
    "Unknown" : "Inconnu",
    "Required" : "Requis",
    "Optional" : "Optionnel",
    "Does not attend" : "Ne participera pas",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Vous êtes dans un fuseau horaire inconnu ({tz}), retour à UTC",
    "Please create a calendar first." : "Veuillez d'abord créer un calendrier.",
    "New event" : "Nouvel événement",
    "CalDAV address for clients" : "Adresse CalDAV pour les clients",
    "Error saving WebCal-calendar" : "Erreur lors de la sauvegarde du calendrier WebCal",
    "WebDAV address for subscriptions" : "Adresse WebDAV pour s'inscrire",
    "Email has been sent." : "L'e-mail a été envoyé.",
    "There was an issue while sending your email." : "Il y a eu un problème lors de l'envoi de votre e-mail.",
    "group" : "groupe",
    "Details" : "Détails",
    "Attendees" : "Participants",
    "Reminders" : "Rappels",
    "Repeating" : "Occurrences",
    "When shared show full event" : "Afficher l'événement complet en cas de partage",
    "When shared show only busy" : "Afficher seulement la plage horaire occupée en cas de partage",
    "When shared hide this event" : "Masquer cet événement en cas de partage",
    "Confirmed" : "Confirmé",
    "Tentative" : "Tentative",
    "Cancelled" : "Annulé",
    "Please add a title." : "Veuillez ajouter un titre.",
    "Please select a calendar." : "Veuillez sélectionner un calendrier.",
    "The event can not end before it starts." : "L'évènement ne peut pas se terminer avant qu'il ne commence.",
    "Global" : "Global",
    "None" : "Aucun",
    "Every day" : "Chaque jour",
    "Every week" : "Chaque semaine",
    "Every month" : "Chaque mois",
    "Every year" : "Chaque année",
    "never" : "jamais",
    "after" : "après ",
    "How about getting started by importing some calendars?" : "Pourquoi ne pas commencer par importer quelques calendriers ?",
    "At time of event" : "À l'heure de l'événement",
    "5 minutes before" : "5 minutes avant",
    "10 minutes before" : "10 minutes avant",
    "15 minutes before" : "15 minutes avant",
    "30 minutes before" : "30 minutes avant",
    "1 hour before" : "1 heure avant",
    "2 hours before" : "2 heures avant",
    "Custom" : "Personnalisé",
    "Audio" : "Son",
    "Email" : "Adresse e-mail",
    "Pop-up" : "Fenêtre d'alerte",
    "sec" : "sec",
    "min" : "min",
    "hours" : "heures",
    "days" : "jours",
    "week" : "semaine",
    "before" : "avant",
    "start" : "début",
    "end" : "fin",
    "Editing reminders of unknown type not supported." : "L'édition de rappels de type inconnu n'est pas supportée.",
    "Week {number} of {year}" : "Semaine {number} de {year}",
    "Successfully imported" : "Importé avec succès",
    "Partially imported, 1 failure" : "Partiellement importé, 1 échec",
    "Partially imported, {n} failures" : "Partiellement importé, {n} échecs",
    "Audio alarm" : "Alerte audio",
    "{type} {time} before the event starts" : "{type} {time} avant l'événement",
    "{type} {time} before the event ends" : "{type} {time} avant la fin de l'événement",
    "{type} {time} after the event starts" : "{type} {time} après le début de l'événement",
    "{type} {time} after the event ends" : "{type} {time} après la fin de l'événement",
    "{type} at the event's start" : "{type} au début de l'événement",
    "{type} at the event's end" : "{type} à la fin de l'événement",
    "{type} at {time}" : "{type} à {time}",
    "{calendar} shared by {owner}" : "{calendar} partagé par {owner}",
    "Please enter a valid WebCal-URL" : "Veuillez saisir une URL WebCal valide",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Erreur grave du mandataire webcal.  Communiquez avec votre administrateur de réseau pour plus de renseignements.",
    "Title of the Event" : "Titre de l'événement",
    "Starts" : "Commence",
    "Ends" : "Termine",
    "All day Event" : "Journée entière",
    "Delete" : "Supprimer",
    "Cancel" : "Annuler",
    "More ..." : "Plus…",
    "Create" : "Créer",
    "Update" : "Mettre à jour",
    "Close" : "Fermer",
    "Location" : "Emplacement",
    "Description" : "Description",
    "Event status" : "Statut de l'événement",
    "Visibility when sharing" : "Visibilité pendant le partage",
    "Export" : "Exporter",
    "%s has published the calendar %s" : "%s a publié l'agenda %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Nous voulions vous informer que %s a publié l'agenda {boldstart}%s{boldend}.",
    "Click here to access it" : "Cliquez ici pour y accéder",
    "We wanted to inform you that %s has published the calendar %s." : "Nous voulions vous informer que %s a publié l'agenda %s.",
    "Click on the link below to access it" : "Cliquez sur le lien ci-dessous pour y accéder",
    "Day" : "Jour",
    "Week" : "Semaine",
    "Month" : "Mois",
    "Today" : "Auj.",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Certains événements de cet agenda sont cassés. Merci de consulter la console JS pour plus d'info.",
    "Share Calendar" : "Partager l'agenda",
    "Shared" : "Partagé",
    "More" : "Plus",
    "Edit" : "Éditer",
    "Link" : "Lien",
    "iCal link" : "Lien iCal",
    "Download" : "Télécharger",
    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
    "can edit" : "peut modifier",
    "Share link" : "Partager un lien",
    "Public access" : "Accès public",
    "Email link to person" : "Envoyer un lien par courriel",
    "Send" : "Envoyer",
    "New Calendar" : "Nouvel agenda",
    "Name" : "Nom",
    "New Subscription" : "Nouvel abonnement",
    "Go back" : "Aller au précédent",
    "Go forward" : "Aller au suivant",
    "Calendar does not exist" : "L'agenda n'existe pas",
    "Maybe you got a wrong link or the calendar was unshared?" : "Vous avez peut-être obtenu un mauvais lien ou le partage de l'agenda a été annulé ?",
    "Edit event" : "Modifier l'événement",
    "Delete Event" : "Supprimer l'événement",
    "Save Event" : "Enregistrer l'événement",
    "Time" : "Heure",
    "Type" : "Type",
    "Relative" : "Relatif",
    "Absolute" : "Absolu",
    "Repeat" : "Répéter",
    "times every" : "Répéter tous les",
    "Add" : "Ajouter",
    "Email address of attendee" : "Adresse e-mail du participant",
    "Please add your email address in the personal settings in order to add attendees." : "Veuillez ajouter votre adresse mail dans les paramètres du compte afin d'ajouter des participants .",
    "from" : "du",
    "to" : "vers",
    "This event's repeating rule is not supported yet." : "La répétition de cet évènement n'est pas prise en charge pour le moment.",
    "Support for advanced rules will be added with subsequent updates." : "Le support de règles multiples sera ajouté dans des mises à jour ultérieures.",
    "Reset repeating rule" : "Réinitialiser la règle de répétition",
    "Repeat every ..." : "Répéter tous les…",
    "end repeat ..." : "arrêter la répétition…",
    "times" : "fois",
    "Import Calendars" : "Importer des agendas",
    "Import canceled" : "Importation annulée",
    "Analyzing calendar" : "Analyse de l'agenda en cours",
    "The file contains objects incompatible with the selected calendar" : "Le fichier contient des objets incompatibles avec l'agenda sélectionné",
    "New calendar" : "Nouvel agenda",
    "File is empty" : "Le fichier est vide",
    "Import scheduled" : "Importation planifiée",
    "%s shared the calendar <strong>%s</strong> with you" : "%s a partagé l'agenda <strong>%s</strong> avec vous",
    "Embed" : "Embarquer",
    "Iframe to integrate" : "Iframe à intégrer",
    "Publish URL" : "Publier l'URL",
    "Settings & import" : "Paramètres & Importation",
    "Skip simple event editor" : "Passer l'éditeur d'évènement simple",
    "Show week numbers" : "Afficher les numéros de semaine",
    "Import calendar" : "Importer un agenda",
    "No Calendars selected for import" : "Aucun agenda sélectionné pour import",
    "Primary CalDAV address" : "Adresse CalDAV principale",
    "iOS/OS X CalDAV address" : "Adresse CalDAV pour iOS/OS X",
    "Subscribe" : "S'abonner"
},
"nplurals=2; plural=(n > 1);");
